##  Displaying Relation Labels
To add relation labels for the fact sheets in a free draw diagram, do the following:
  1. Open a free draw diagram.
  2. Select Labels.
  3. Go to Relation > Name.


Relation Labels
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2ed2fc14d7af4f81a21284352ea1356c_LowRes.png)
